@@ -52,14 +52,17 @@ class TestTriggerController(base.TestCase):
         assembly_uuid, plan_uuid, trigger_uri = self._create_assembly()
         #Using requests instead of self.client to test unauthenticated request
         resp = requests.post(trigger_uri)
-        self.assertEqual(resp.status_code, 200)
+        self.assertEqual(resp.status_code, 202)
 
         self._delete_assembly(assembly_uuid, plan_uuid)
 
     def _delete_assembly(self, assembly_uuid, plan_uuid):
         resp, body = self.client.delete('v1/assemblies/%s' % assembly_uuid)
         self.assertEqual(resp.status, 204)
-        self._delete_plan(plan_uuid)
+        if self.client.assembly_delete_done(assembly_uuid):
+            self._delete_plan(plan_uuid)
+        else:
+            self.fail("Assembly couldn't be deleted.")
 
     def _delete_plan(self, plan_uuid):
         resp, body = self.client.delete('v1/plans/%s' % plan_uuid)
