@@ -17,6 +17,7 @@
 import json
 
 from functionaltests.api import base
+from tempest import exceptions as tempest_exceptions
 
 sample_data = {"name": "test_assembly",
                "description": "A test to create assembly",
@@ -44,7 +45,11 @@ class TestAssemblyController(base.TestCase):
     def _delete_assembly(self, uuid, plan_uuid):
         resp, _ = self.client.delete('v1/assemblies/%s' % uuid)
         self.assertEqual(resp.status, 204)
-        self._delete_plan(plan_uuid)
+
+        if self.client.assembly_delete_done(uuid):
+            self._delete_plan(plan_uuid)
+        else:
+            self.assertRaises(tempest_exceptions.TimeoutException)
 
     def _delete_plan(self, plan_uuid):
         resp, _ = self.client.delete('v1/plans/%s' % plan_uuid)
@@ -88,6 +93,10 @@ class TestAssemblyController(base.TestCase):
         self._assert_output_expected(json_data, sample_data)
         self._delete_assembly(json_data['uuid'], p_uuid)
 
+    def test_assemblies_create_none(self):
+        self.assertRaises(tempest_exceptions.BadRequest,
+                          self.client.post, 'v1/assemblies', "{}")
+
     def test_assemblies_get(self):
         uuid, plan_uuid = self._create_assembly()
         sample_data['plan_uri'] = "%s/v1/plans/%s" % (self.client.base_url,
@@ -98,10 +107,14 @@ class TestAssemblyController(base.TestCase):
         self._assert_output_expected(json_data, sample_data)
         self._delete_assembly(uuid, plan_uuid)
 
+    def test_assemblies_get_not_found(self):
+        self.assertRaises(tempest_exceptions.NotFound,
+                          self.client.get, 'v1/assemblies/not_found')
+
     def test_assemblies_put(self):
         uuid, plan_uuid = self._create_assembly()
         uri = "%s/v1/plans/%s" % (self.client.base_url, plan_uuid)
-        updated_data = {"name": "test_assembly updated",
+        updated_data = {"name": "test_assembly_updated",
                         "description": "A test to create assembly updated",
                         "plan_uri": uri,
                         "project_id": "project_id updated",
@@ -115,9 +128,33 @@ class TestAssemblyController(base.TestCase):
         self._assert_output_expected(json_data, updated_data)
         self._delete_assembly(uuid, plan_uuid)
 
+    def test_assemblies_put_not_found(self):
+        updated_data = {"name": "test_assembly_updated",
+                        "description": "A test to create assembly updated",
+                        "plan_uri": 'fake_uri',
+                        "project_id": "project_id updated",
+                        "user_id": "user_id updated",
+                        "status": "new_status",
+                        "application_uri": "new_uri"}
+        updated_json = json.dumps(updated_data)
+        self.assertRaises(tempest_exceptions.NotFound,
+                          self.client.put, 'v1/assemblies/not_found',
+                          updated_json)
+
+    def test_assemblies_put_none(self):
+        self.assertRaises(tempest_exceptions.BadRequest,
+                          self.client.put, 'v1/assemblies/any', "{}")
+
     def test_assemblies_delete(self):
         uuid, plan_uuid = self._create_assembly()
         resp, body = self.client.delete('v1/assemblies/%s' % uuid)
         self.assertEqual(resp.status, 204)
         self.assertEqual(body, '')
-        self._delete_plan(plan_uuid)
+        if self.client.assembly_delete_done(uuid):
+            self._delete_plan(plan_uuid)
+        else:
+            self.fail("Assembly couldn't be deleted.")
+
+    def test_assemblies_delete_not_found(self):
+        self.assertRaises(tempest_exceptions.NotFound,
+                          self.client.delete, 'v1/assemblies/not_found')
