@@ -46,7 +46,10 @@ class TestComponentController(base.TestCase):
     def _delete_assembly(self, assembly_uuid, plan_uuid):
         resp, body = self.client.delete('v1/assemblies/%s' % assembly_uuid)
         self.assertEqual(resp.status, 204)
-        self._delete_plan(plan_uuid)
+        if self.client.assembly_delete_done(assembly_uuid):
+            self._delete_plan(plan_uuid)
+        else:
+            self.fail("Assembly couldn't be deleted.")
 
     def _delete_plan(self, plan_uuid):
         resp, body = self.client.delete('v1/plans/%s' % plan_uuid)
@@ -102,6 +105,10 @@ class TestComponentController(base.TestCase):
         self._assert_output_expected(json_data, sample_data)
         self._delete_component(json_data['uuid'], assembly_uuid, plan_uuid)
 
+    def test_components_create_none(self):
+        self.assertRaises(tempest_exceptions.BadRequest,
+                          self.client.post, 'v1/components', "{}")
+
     def test_components_get(self):
         uuid, assembly_uuid, plan_uuid = self._create_component()
         sample_data['plan_uri'] = "%s/v1/plans/%s" % (self.client.base_url,
@@ -112,13 +119,13 @@ class TestComponentController(base.TestCase):
         self._assert_output_expected(json_data, sample_data)
         self._delete_component(uuid, assembly_uuid, plan_uuid)
 
-    def test_components_get_notfound(self):
+    def test_components_get_not_found(self):
         self.assertRaises(tempest_exceptions.NotFound,
                           self.client.get, 'v1/components/not_found')
 
     def test_components_put(self):
         uuid, assembly_uuid, plan_uuid = self._create_component()
-        updated_data = {'name': 'test_service updated',
+        updated_data = {'name': 'test_service_updated',
                         'description': 'desc updated',
                         'plan_uri': "%s/v1/plans/%s" % (self.client.base_url,
                                                         plan_uuid),
@@ -130,9 +137,28 @@ class TestComponentController(base.TestCase):
         self._assert_output_expected(json_data, updated_data)
         self._delete_component(uuid, assembly_uuid, plan_uuid)
 
+    def test_components_put_not_found(self):
+        updated_data = {'name': 'test_service_updated',
+                        'description': 'desc updated',
+                        'plan_uri': "%s/v1/plans/%s" % (self.client.base_url,
+                                                        'not_found'),
+                        'assembly_uuid': 'not_found'}
+        updated_json = json.dumps(updated_data)
+        self.assertRaises(tempest_exceptions.NotFound,
+                          self.client.put, 'v1/components/not_found',
+                          updated_json)
+
+    def test_components_put_none(self):
+        self.assertRaises(tempest_exceptions.BadRequest,
+                          self.client.put, 'v1/components/any', "{}")
+
     def test_components_delete(self):
         uuid, assembly_uuid, plan_uuid = self._create_component()
         resp, body = self.client.delete('v1/components/%s' % uuid)
         self.assertEqual(resp.status, 204)
         self.assertEqual(body, '')
         self._delete_assembly(assembly_uuid, plan_uuid)
+
+    def test_components_delete_not_found(self):
+        self.assertRaises(tempest_exceptions.NotFound,
+                          self.client.delete, 'v1/components/not_found')
