@@ -16,6 +16,7 @@
 import json
 
 from functionaltests.api import base
+from tempest import exceptions as tempest_exceptions
 
 sample_data = {"name": "test_plan",
                "description": "A test to create plan",
@@ -23,7 +24,7 @@ sample_data = {"name": "test_plan",
                "user_id": "user_id",
                "type": "plan",
                "artifacts": [{
-                   "name": "No deus",
+                   "name": "No_deus",
                    "artifact_type": "application.heroku",
                    "content": {
                        "href": "https://example.com/git/a.git"
@@ -79,6 +80,10 @@ class TestPlanController(base.TestCase):
         self._assert_output_expected(json_data, sample_data)
         self._delete_plan(json_data['uuid'])
 
+    def test_plans_create_none(self):
+        self.assertRaises(tempest_exceptions.BadRequest,
+                          self.client.post, 'v1/plans', "{}")
+
     def test_plans_get(self):
         uuid = self._create_plan()
         resp, body = self.client.get('v1/plans/%s' % uuid)
@@ -87,9 +92,13 @@ class TestPlanController(base.TestCase):
         self._assert_output_expected(json_data, sample_data)
         self._delete_plan(uuid)
 
+    def test_plans_get_not_found(self):
+        self.assertRaises(tempest_exceptions.NotFound,
+                          self.client.get, 'v1/plans/not_found')
+
     def test_plans_put(self):
         uuid = self._create_plan()
-        updated_data = {"name": "test_plan updated",
+        updated_data = {"name": "test_plan_updated",
                         "description": "A test to create plan updated",
                         "type": "plan",
                         "artifacts": []}
@@ -100,8 +109,25 @@ class TestPlanController(base.TestCase):
         self._assert_output_expected(json_data, updated_data)
         self._delete_plan(uuid)
 
+    def test_plans_put_not_found(self):
+        updated_data = {"name": "test_plan_updated",
+                        "description": "A test to create plan updated",
+                        "type": "plan",
+                        "artifacts": []}
+        updated_json = json.dumps(updated_data)
+        self.assertRaises(tempest_exceptions.NotFound,
+                          self.client.put, 'v1/plans/not_found', updated_json)
+
+    def test_plans_put_none(self):
+        self.assertRaises(tempest_exceptions.BadRequest,
+                          self.client.put, 'v1/plans/any', "{}")
+
     def test_plans_delete(self):
         uuid = self._create_plan()
         resp, body = self.client.delete('v1/plans/%s' % uuid)
         self.assertEqual(resp.status, 204)
         self.assertEqual(body, '')
+
+    def test_plans_delete_not_found(self):
+        self.assertRaises(tempest_exceptions.NotFound,
+                          self.client.delete, 'v1/plans/not_found')
