@@ -14,32 +14,33 @@
 
 """Starter script for the Solum Conductor service."""
 
+import logging as std_logging
 import os
 import sys
 
-from oslo_config import cfg
-from oslo_log import log as logging
+from oslo.config import cfg
 
-from solum.common.rpc import service as rpc_service
-from solum.common import service
+from solum.common.rpc import service
 from solum.conductor.handlers import default as default_handler
-from solum.i18n import _
+from solum.openstack.common.gettextutils import _
+from solum.openstack.common import log as logging
 
 LOG = logging.getLogger(__name__)
 
 
 def main():
-    service.prepare_service(sys.argv)
+    cfg.CONF(sys.argv[1:], project='solum')
+    logging.setup('solum')
 
     LOG.info(_('Starting server in PID %s') % os.getpid())
-    LOG.debug("Configuration:")
-    logging.setup(cfg.CONF, 'solum')
+    LOG.debug(_("Configuration:"))
+    cfg.CONF.log_opt_values(LOG, std_logging.DEBUG)
 
     cfg.CONF.import_opt('topic', 'solum.conductor.config', group='conductor')
     cfg.CONF.import_opt('host', 'solum.conductor.config', group='conductor')
     endpoints = [
         default_handler.Handler(),
     ]
-    server = rpc_service.Service(cfg.CONF.conductor.topic,
-                                 cfg.CONF.conductor.host, endpoints)
+    server = service.Service(cfg.CONF.conductor.topic,
+                             cfg.CONF.conductor.host, endpoints)
     server.serve()
