@@ -14,27 +14,28 @@
 
 """Starter script for the Solum Deployer service."""
 
+import logging as std_logging
 import os
 import sys
 
-from oslo_config import cfg
-from oslo_log import log as logging
+from oslo.config import cfg
 
-from solum.common.rpc import service as rpc_service
-from solum.common import service
+from solum.common.rpc import service
 from solum.deployer.handlers import heat as heat_handler
 from solum.deployer.handlers import noop as noop_handler
 from solum.openstack.common.gettextutils import _
+from solum.openstack.common import log as logging
 
 LOG = logging.getLogger(__name__)
 
 
 def main():
-    service.prepare_service(sys.argv)
+    cfg.CONF(sys.argv[1:], project='solum')
+    logging.setup('solum')
 
     LOG.info(_('Starting server in PID %s') % os.getpid())
-    LOG.debug("Configuration:")
-    logging.setup(cfg.CONF, 'solum')
+    LOG.debug(_("Configuration:"))
+    cfg.CONF.log_opt_values(LOG, std_logging.DEBUG)
 
     cfg.CONF.import_opt('topic', 'solum.deployer.config', group='deployer')
     cfg.CONF.import_opt('host', 'solum.deployer.config', group='deployer')
@@ -49,6 +50,6 @@ def main():
         handlers[cfg.CONF.deployer.handler](),
     ]
 
-    server = rpc_service.Service(cfg.CONF.deployer.topic,
-                                 cfg.CONF.deployer.host, endpoints)
+    server = service.Service(cfg.CONF.deployer.topic,
+                             cfg.CONF.deployer.host, endpoints)
     server.serve()
