@@ -14,12 +14,12 @@
 
 from glanceclient import client as glanceclient
 from heatclient import client as heatclient
-from keystoneclient.v2_0 import client as ksclient
 from neutronclient.neutron import client as neutronclient
 from oslo.config import cfg
 from swiftclient import client as swiftclient
 
 from solum.common import exception
+from solum.common import solum_keystoneclient
 from solum.openstack.common.gettextutils import _
 from solum.openstack.common import log as logging
 
@@ -99,6 +99,13 @@ class OpenStackClients(object):
         self._neutron = None
         self._swift = None
 
+    def url_for(self, **kwargs):
+        return self.keystone().client.service_catalog.url_for(**kwargs)
+
+    @property
+    def auth_url(self):
+        return self.keystone().v3_endpoint
+
     @property
     def auth_token(self):
         return self.context.auth_token or self.keystone().auth_token
@@ -107,13 +114,7 @@ class OpenStackClients(object):
         if self._keystone:
             return self._keystone
 
-        args = {
-            'auth_url': self.context.auth_url,
-            'token': self.context.auth_token,
-            'username': None,
-            'password': None
-        }
-        self._keystone = ksclient.Client(**args)
+        self._keystone = solum_keystoneclient.KeystoneClientV3(self.context)
         return self._keystone
 
     @exception.wrap_keystone_exception
@@ -122,10 +123,10 @@ class OpenStackClients(object):
             return self._neutron
 
         endpoint_type = self._get_client_option('neutron', 'endpoint_type')
-        endpoint_url = self.context.get_url_for(service_type='network',
-                                                endpoint_type=endpoint_type)
+        endpoint_url = self.url_for(service_type='network',
+                                    endpoint_type=endpoint_type)
         args = {
-            'auth_url': self.context.auth_url,
+            'auth_url': self.auth_url,
             'endpoint_url': endpoint_url,
             'token': self.auth_token,
             'username': None,
@@ -148,8 +149,8 @@ class OpenStackClients(object):
             'token': self.auth_token,
         }
         endpoint_type = self._get_client_option('glance', 'endpoint_type')
-        endpoint = self.context.get_url_for(service_type='image',
-                                            endpoint_type=endpoint_type)
+        endpoint = self.url_for(service_type='image',
+                                endpoint_type=endpoint_type)
         self._glance = glanceclient.Client('2', endpoint, **args)
 
         return self._glance
@@ -161,7 +162,7 @@ class OpenStackClients(object):
 
         endpoint_type = self._get_client_option('heat', 'endpoint_type')
         args = {
-            'auth_url': self.context.auth_url,
+            'auth_url': self.auth_url,
             'token': self.auth_token,
             'username': None,
             'password': None,
@@ -171,8 +172,8 @@ class OpenStackClients(object):
             'insecure': self._get_client_option('heat', 'insecure')
         }
 
-        endpoint = self.context.get_url_for(service_type='orchestration',
-                                            endpoint_type=endpoint_type)
+        endpoint = self.url_for(service_type='orchestration',
+                                endpoint_type=endpoint_type)
         self._heat = heatclient.Client('1', endpoint, **args)
 
         return self._heat
@@ -186,8 +187,8 @@ class OpenStackClients(object):
         args = {
             'auth_version': '2.0',
             'preauthtoken': self.auth_token,
-            'preauthurl': self.context.get_url_for(
-                service_type='object-store', endpoint_type=endpoint_type),
+            'preauthurl': self.url_for(service_type='object-store',
+                                       endpoint_type=endpoint_type),
             'os_options': {'endpoint_type': endpoint_type},
             'cacert': self._get_client_option('swift', 'cacert'),
             'insecure': self._get_client_option('swift', 'insecure')
