@@ -21,11 +21,12 @@ Includes decorator for re-raising Solum-type exceptions.
 import functools
 import pecan
 import sys
-import wsme
+import uuid
 
 from keystoneclient import exceptions as keystone_exceptions
 from oslo.config import cfg
 import six
+import wsme
 
 from solum.common import safe_utils
 from solum.openstack.common import excutils
@@ -38,7 +39,7 @@ LOG = logging.getLogger(__name__)
 exc_log_opts = [
     cfg.BoolOpt('fatal_exception_format_errors',
                 default=False,
-                help='make exception message format errors fatal'),
+                help='make exception message format errors fatal')
 ]
 
 CONF = cfg.CONF
@@ -85,20 +86,76 @@ def wrap_exception(notifier=None, publisher_id=None, event_type=None,
     return inner
 
 
-def wrap_controller_exception(func):
-    """This decorator wraps controllers method to manage wsme exceptions:
-    a wsme ClientSideError is raised if a SolumException is thrown.
+OBFUSCATED_MSG = _('Your request could not be handled '
+                   'because of a problem in the server. '
+                   'Error Correlation id is: %s')
+
+
+def wrap_controller_exception(func, func_server_error, func_client_error):
+    """This decorator wraps controllers methods to handle exceptions:
+
+    - if an unhandled Exception or a SolumException with an error code >=500
+    is catched, raise a http 5xx ClientSideError and correlates it with a log
+    message
+
+    - if a SolumException is catched and its error code is <500, raise a http
+    4xx and logs the excp in debug mode
+
     """
     @functools.wraps(func)
     def wrapped(*args, **kw):
         try:
             return func(*args, **kw)
-        except SolumException as excp:
-            pecan.response.translatable_error = excp
-            raise wsme.exc.ClientSideError(six.text_type(excp), excp.code)
+        except Exception as excp:
+            if isinstance(excp, SolumException):
+                http_error_code = excp.code
+            else:
+                http_error_code = 500
+
+            if http_error_code >= 500:
+                # log the error message with its associated
+                # correlation id
+                log_correlation_id = str(uuid.uuid4())
+                LOG.error("%s:%s", log_correlation_id, str(excp))
+                # raise a client error with an obfuscated message
+                func_server_error(log_correlation_id, http_error_code)
+            else:
+                # raise a client error the original message
+                LOG.debug(excp)
+                func_client_error(excp, http_error_code)
     return wrapped
 
 
+def wrap_wsme_controller_exception(func):
+    """This decorator wraps wsme controllers to handle exceptions."""
+    def _func_server_error(log_correlation_id, status_code):
+        raise wsme.exc.ClientSideError(
+            six.text_type(OBFUSCATED_MSG % log_correlation_id), status_code)
+
+    def _func_client_error(excp, status_code):
+        raise wsme.exc.ClientSideError(six.text_type(excp), status_code)
+
+    return wrap_controller_exception(func,
+                                     _func_server_error,
+                                     _func_client_error)
+
+
+def wrap_pecan_controller_exception(func):
+    """This decorator wraps pecan controllers to handle exceptions."""
+    def _func_server_error(log_correlation_id, status_code):
+        pecan.response.status = status_code
+        pecan.response.body = six.text_type(OBFUSCATED_MSG %
+                                            log_correlation_id)
+
+    def _func_client_error(excp, status_code):
+        pecan.response.status = status_code
+        pecan.response.body = six.text_type(excp)
+
+    return wrap_controller_exception(func,
+                                     _func_server_error,
+                                     _func_client_error)
+
+
 def wrap_keystone_exception(func):
     """This decorator wraps keystone exception by throwing Solum specific
     exceptions.
