@@ -20,7 +20,7 @@ import six
 # can be relaxed more as needed.  This is only used if import_context() is
 # called.
 _TRACE_USER_KEYS = [six.u("user"), six.u("tenant")]
-_TRACE_CONTEXT_IGNORE = [six.u("auth_token"), six.u("service_catalog")]
+_TRACE_CONTEXT_IGNORE = [six.u("auth_token"), six.u("trust_id")]
 
 
 class TraceData(object):
