@@ -14,7 +14,6 @@
 
 """Solum Conductor default handler."""
 
-from solum.deployer import api
 from solum import objects
 from solum.objects import image
 from solum.openstack.common.gettextutils import _
@@ -33,11 +32,11 @@ class Handler(object):
     def echo(self, ctxt, message):
         LOG.debug(_("%s") % message)
 
-    def build_job_update(self, ctxt, build_id, status, reason,
+    def build_job_update(self, ctxt, build_id, state, description,
                          created_image_id, assembly_id):
         image = objects.registry.Image.get_by_id(ctxt, build_id)
-        image.status = status
-        image.reason = reason
+        image.state = state
+        image.description = description
         image.created_image_id = created_image_id
         image.save(ctxt)
 
@@ -51,6 +50,3 @@ class Handler(object):
                                                              'Image Build',
                                                              'Image Build job',
                                                              created_image_id)
-            if image.status == IMAGE_STATES.COMPLETE:
-                api.API(context=ctxt).deploy(assembly_id=assem.id,
-                                             image_id=image.created_image_id)
