@@ -18,6 +18,7 @@ import os
 import time
 import yaml
 
+from heatclient import exc
 from oslo.config import cfg
 from solum.common import clients
 from solum import objects
@@ -83,6 +84,32 @@ class Handler(object):
                 params['private_subnet'] = tenant_network['subnets'][0]
         return params
 
+    def delete_heat_stack(self, ctxt, assem_id):
+        osc = clients.OpenStackClients(ctxt)
+        assem = objects.registry.Assembly.get_by_id(ctxt, assem_id)
+        stack_id = self._find_id_if_stack_exists(osc, assem.name)
+
+        if stack_id is not None:
+            osc.heat().stacks.delete(stack_id)
+
+            wait_interval = cfg.CONF.deployer.wait_interval
+            growth_factor = cfg.CONF.deployer.growth_factor
+
+            for count in range(cfg.CONF.deployer.max_attempts):
+                stack_id = self._find_id_if_stack_exists(osc, assem.name)
+                if stack_id is None:
+                    break
+                time.sleep(wait_interval)
+                wait_interval *= growth_factor
+
+        if stack_id is None:
+            assem.destroy(ctxt)
+            return
+
+        if stack_id is not None:
+            assem.status = STATES.ERROR_STACK_DELETE_FAILED
+            assem.save(ctxt)
+
     def deploy(self, ctxt, assembly_id, image_id):
         osc = clients.OpenStackClients(ctxt)
 
@@ -93,29 +120,33 @@ class Handler(object):
 
         # TODO(asalkeld) support template flavors (maybe an autoscaling one)
         #                this could also be stored in glance.
-        if cfg.CONF.api.image_format == 'qcow2':
-            parameters.update(self._get_network_parameters(osc))
-            template_flavor = 'basic'
-        else:
-            #Docker does not support floating IP right now, so we use a
-            # template without neutron
-            template_flavor = 'basic_for_docker'
+
+        parameters.update(self._get_network_parameters(osc))
+        template_flavor = 'basic'
 
         template = self._get_template(template_flavor)
-        created_stack = osc.heat().stacks.create(stack_name=assem.name,
-                                                 template=template,
-                                                 parameters=parameters)
+
+        stack_id = self._find_id_if_stack_exists(osc, assem.name)
+        if stack_id is not None:
+            osc.heat().stacks.update(stack_id,
+                                     stack_name=assem.name,
+                                     template=template,
+                                     parameters=parameters)
+        else:
+            created_stack = osc.heat().stacks.create(stack_name=assem.name,
+                                                     template=template,
+                                                     parameters=parameters)
+            stack_id = created_stack['stack']['id']
+
+            comp_description = 'Heat Stack %s' % (
+                yaml.load(template).get('description'))
+            objects.registry.Component.assign_and_create(ctxt, assem,
+                                                         'Heat Stack',
+                                                         comp_description,
+                                                         created_stack['stack']
+                                                         ['links'][0]['href'])
         assem.status = STATES.DEPLOYING
         assem.save(ctxt)
-        stack_id = created_stack['stack']['id']
-
-        comp_description = 'Heat Stack %s' % (
-            yaml.load(template).get('description'))
-        objects.registry.Component.assign_and_create(ctxt, assem,
-                                                     'Heat Stack',
-                                                     comp_description,
-                                                     created_stack['stack']
-                                                     ['links'][0]['href'])
 
         self._update_assembly_status(ctxt, assem, osc, stack_id)
 
@@ -153,3 +184,11 @@ class Handler(object):
         if 'outputs' in heat_output._info:
             return heat_output._info['outputs'][1]['output_value']
         return None
+
+    def _find_id_if_stack_exists(self, osc, stack_name):
+        try:
+            stack = osc.heat().stacks.get(stack_name)
+            if stack is not None:
+                return stack.identifier.split('/')[-1]
+        except exc.HTTPNotFound:
+            return None
