@@ -30,4 +30,6 @@ class States(object):
     DEPLOYING = 'DEPLOYING'
     ERROR = 'ERROR'
     READY = 'READY'
+    DELETING = 'DELETING'
+    ERROR_STACK_DELETE_FAILED = 'ERROR_STACK_DELETE_FAILED'
     ERROR_STACK_CREATE_FAILED = 'ERROR_STACK_CREATE_FAILED'
