@@ -18,6 +18,7 @@ SQLAlchemy models for application data.
 
 import json
 import six
+import yaml
 
 from oslo.config import cfg
 from sqlalchemy.ext import declarative
@@ -128,9 +129,8 @@ class SolumBase(models.TimestampMixin, models.ModelBase):
     def destroy(self, context):
         session = SolumBase.get_session()
         with session.begin():
-            session.query(self.__class__).\
-                filter_by(id=self.id).\
-                delete()
+            session.query(self.__class__).filter_by(
+                id=self.id).delete()
 
     @classmethod
     def _raise_not_found(cls, item_id):
@@ -158,3 +158,19 @@ class JSONEncodedDict(types.TypeDecorator):
         if value is not None:
             value = json.loads(value)
         return value
+
+
+class YAMLEncodedDict(types.TypeDecorator):
+    """Represents an immutable structure as a yaml-encoded string."""
+
+    impl = types.VARCHAR
+
+    def process_bind_param(self, value, dialect):
+        if value is not None:
+            value = yaml.dump(value)
+        return value
+
+    def process_result_value(self, value, dialect):
+        if value is not None:
+            value = yaml.load(value)
+        return value
