@@ -31,8 +31,8 @@ class TestComponentHandler(base.BaseTestCase):
         handler = component_handler.ComponentHandler(self.ctx)
         res = handler.get('test_id')
         self.assertIsNotNone(res)
-        get_by_uuid = mock_registry.Component.get_by_uuid
-        get_by_uuid.assert_called_once_with(self.ctx, 'test_id')
+        mock_registry.Component.get_by_uuid.\
+            assert_called_once_with(self.ctx, 'test_id')
 
     def test_get_all(self, mock_registry):
         mock_registry.ComponentList.get_all.return_value = {}
@@ -44,10 +44,15 @@ class TestComponentHandler(base.BaseTestCase):
     def test_update(self, mock_registry):
         data = {'user_id': 'new_user_id',
                 'assembly_id': 'new_assembly_id'}
+        db_obj = fakes.FakeComponent()
+        mock_registry.Component.get_by_uuid.return_value = db_obj
         handler = component_handler.ComponentHandler(self.ctx)
-        handler.update('test_id', data)
-        mock_registry.Component.update_and_save.assert_called_once_with(
-            self.ctx, 'test_id', data)
+        res = handler.update('test_id', data)
+        self.assertEqual(db_obj.user_id, res.user_id)
+        db_obj.update.assert_called_once_with(data)
+        db_obj.save.assert_called_once_with(self.ctx)
+        mock_registry.Component.get_by_uuid.assert_called_once_with(self.ctx,
+                                                                    'test_id')
 
     def test_create(self, mock_registry):
         data = {'name': 'new_name',
