@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -42,10 +44,15 @@ class TestOperationHandler(base.BaseTestCase):
 
     def test_update(self, mock_registry):
         data = {'user_id': 'new_user_id'}
+        db_obj = fakes.FakeOperation()
+        mock_registry.Operation.get_by_uuid.return_value = db_obj
         handler = operation.OperationHandler(self.ctx)
-        handler.update('test_id', data)
-        mock_registry.Operation.update_and_save.assert_called_once_with(
-            self.ctx, 'test_id', data)
+        res = handler.update('test_id', data)
+        self.assertEqual(db_obj.user_id, res.user_id)
+        db_obj.save.assert_called_once_with(self.ctx)
+        db_obj.update.assert_called_once_with(data)
+        mock_registry.Operation.get_by_uuid.assert_called_once_with(self.ctx,
+                                                                    'test_id')
 
     def test_create(self, mock_registry):
         data = {'user_id': 'new_user_id'}
