@@ -15,11 +15,12 @@
 # under the License.
 
 from oslo.config import cfg
+import testscenarios
 
 from solum.openstack.common import test
 
 
-class BaseTestCase(test.BaseTestCase):
+class BaseTestCase(testscenarios.WithScenarios, test.BaseTestCase):
     """Test base class."""
 
     def setUp(self):
