@@ -12,20 +12,19 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from unittest import mock
+import mock
+from oslo.config import cfg
 
-from oslo_config import cfg
+cfg.CONF.import_group('keystone_authtoken',
+                      'keystoneclient.middleware.auth_token')
 
-import keystoneclient.exceptions as kc_exception  # noqa
+import keystoneclient.exceptions as kc_exception
 
 from solum.common import exception
 from solum.common import solum_keystoneclient
 from solum.tests import base
 from solum.tests import utils
 
-cfg.CONF.import_group('keystone_authtoken',
-                      'keystonemiddleware.auth_token')
-
 
 @mock.patch('keystoneclient.v3.client.Client')
 class KeystoneClientTest(base.BaseTestCase):
@@ -38,15 +37,18 @@ class KeystoneClientTest(base.BaseTestCase):
         self.ctx = utils.dummy_context()
         self.ctx.auth_url = dummy_url
         self.ctx.auth_token = 'abcd1234'
-        self.ctx.auth_token_info = None
 
-        cfg.CONF.set_override('www_authenticate_uri', dummy_url,
+        cfg.CONF.set_override('auth_uri', dummy_url,
+                              group='keystone_authtoken')
+        cfg.CONF.set_override('admin_user', 'solum',
+                              group='keystone_authtoken')
+        cfg.CONF.set_override('admin_password', 'verybadpass',
+                              group='keystone_authtoken')
+        cfg.CONF.set_override('admin_tenant_name', 'service',
                               group='keystone_authtoken')
 
     def test_init_v3_token(self, mock_ks):
         """Test creating the client, token auth."""
-        # TODO(zhurong): should unskip the test
-        self.skipTest('Skipping this test for bug #1686560')
         self.ctx.tenant = None
         self.ctx.trust_id = None
         solum_ks_client = solum_keystoneclient.KeystoneClientV3(self.ctx)
@@ -66,53 +68,8 @@ class KeystoneClientTest(base.BaseTestCase):
         self.assertRaises(exception.AuthorizationFailure,
                           solum_ks_client._v3_client_init)
 
-    def test_init_trust_token_access(self, mock_ks):
-        """Test creating the client, token auth."""
-        # TODO(zhurong): should unskip the test
-        self.skipTest('Skipping this test for bug #1686560')
-        self.ctx.tenant = 'abcd1234'
-        self.ctx.trust_id = None
-        self.ctx.auth_token_info = {'access': {'token': {'id': 'placeholder'}}}
-
-        solum_ks_client = solum_keystoneclient.KeystoneClientV3(self.ctx)
-        solum_ks_client.client
-        self.assertIsNotNone(solum_ks_client._client)
-        mock_ks.assert_called_once_with(auth_ref={'version': 'v2.0',
-                                                  'token': {
-                                                      'id': 'abcd1234'}},
-                                        endpoint='http://server.test:5000/v3',
-                                        auth_url='http://server.test:5000/v3')
-
-    def test_init_trust_token_token(self, mock_ks):
-        # TODO(zhurong): should unskip the test
-        self.skipTest('Skipping this test for bug #1686560')
-        self.ctx.tenant = None
-        self.ctx.trust_id = None
-        self.ctx.auth_token_info = {'token': {}}
-
-        solum_ks_client = solum_keystoneclient.KeystoneClientV3(self.ctx)
-        solum_ks_client.client
-        self.assertIsNotNone(solum_ks_client._client)
-        mock_ks.assert_called_once_with(auth_ref={'auth_token': 'abcd1234',
-                                                  'version': 'v3'},
-                                        endpoint='http://server.test:5000/v3',
-                                        auth_url='http://server.test:5000/v3')
-
-    def test_init_trust_token_none(self, mock_ks):
-        # TODO(zhurong): should unskip the test
-        self.skipTest('Skipping this test for bug #1686560')
-        self.ctx.tenant = None
-        self.ctx.trust_id = None
-        self.ctx.auth_token_info = {'not_this': 'urg'}
-
-        solum_ks_client = solum_keystoneclient.KeystoneClientV3(self.ctx)
-        self.assertRaises(exception.AuthorizationFailure,
-                          solum_ks_client._v3_client_init)
-
     def test_create_trust_context_trust_id(self, mock_ks):
         """Test create_trust_context with existing trust_id."""
-        # TODO(zhurong): should unskip the test
-        self.skipTest('Skipping this test for bug #1686560')
         self.ctx.trust_id = 'atrust123'
 
         solum_ks_client = solum_keystoneclient.KeystoneClientV3(self.ctx)
@@ -127,9 +84,6 @@ class KeystoneClientTest(base.BaseTestCase):
 
     def test_create_trust_context_trust_create(self, mock_ks):
         """Test create_trust_context when creating a trust."""
-        # TODO(zhurong): should unskip the test
-        self.skipTest('Skipping this test for bug #1686560')
-
         class FakeTrust(object):
             id = 'atrust123'
 
@@ -153,7 +107,7 @@ class KeystoneClientTest(base.BaseTestCase):
                               auth_url='http://server.test:5000/v3',
                               endpoint='http://server.test:5000/v3'),
                     mock.call(token='abcd1234',
-                              project_id='fake_project_id',
+                              project_id='test_tenant_id',
                               auth_url='http://server.test:5000/v3',
                               endpoint='http://server.test:5000/v3')]
 
@@ -172,8 +126,6 @@ class KeystoneClientTest(base.BaseTestCase):
 
     def test_init_admin_client_denied(self, mock_ks):
         """Test the admin_client property, auth failure path."""
-        # TODO(zhurong): should unskip the test
-        self.skipTest('Skipping this test for bug #1686560')
         self.ctx.username = None
         self.ctx.password = None
         self.ctx.trust_id = None
@@ -189,36 +141,8 @@ class KeystoneClientTest(base.BaseTestCase):
         self.assertRaises(exception.AuthorizationFailure,
                           get_admin_client)
 
-    def test_init_lp_admin_client_denied(self, mock_ks):
-        """Test the get_lp_admin_client property, auth failure path."""
-        # TODO(zhurong): should unskip the test
-        self.skipTest('Skipping this test for bug #1686560')
-        self.ctx.username = None
-        self.ctx.password = None
-        self.ctx.trust_id = None
-        mock_ks.return_value.authenticate.return_value = False
-
-        solum_ks_client = solum_keystoneclient.KeystoneClientV3(self.ctx)
-
-        # Define wrapper for property or the property raises the exception
-        # outside of the assertRaises which fails the test
-        def get_lp_admin_client():
-            solum_ks_client.lp_admin_client
-
-        self.assertRaises(exception.AuthorizationFailure,
-                          get_lp_admin_client)
-
-    def test_init_with_no_context(self, mock_ks):
-        """Init with no context."""
-        mock_ks.return_value.authenticate.return_value = False
-        solum_ks_client = solum_keystoneclient.KeystoneClientV3(None)
-        self.assertEqual(solum_ks_client.endpoint,
-                         'http://server.test:5000/v3')
-
     def test_trust_init_fail(self, mock_ks):
         """Test consuming a trust when initializing, error scoping."""
-        # TODO(zhurong): should unskip the test
-        self.skipTest('Skipping this test for bug #1686560')
         self.ctx.username = None
         self.ctx.auth_token = None
         self.ctx.trust_id = 'atrust123'
@@ -229,8 +153,6 @@ class KeystoneClientTest(base.BaseTestCase):
 
     def test_trust_init_token(self, mock_ks):
         """Test trust_id takes precedence when token specified."""
-        # TODO(zhurong): should unskip the test
-        self.skipTest('Skipping this test for bug #1686560')
         self.ctx.username = None
         self.ctx.trust_id = 'atrust123'
         solum_ks_client = solum_keystoneclient.KeystoneClientV3(self.ctx)
