@@ -22,6 +22,7 @@ fakeAuthTokenHeaders = {'X-User-Id': u'773a902f022949619b5c2f32cd89d419',
                         'X-Auth-Token': u'5588aebbcdc24e17a061595f80574376',
                         'X-Forwarded-For': u'10.10.10.10, 11.11.11.11',
                         'X-Service-Catalog': u'{test: 12345}',
+                        'X-Auth-Url': 'fake_auth_url',
                         'X-Identity-Status': 'Confirmed',
                         'X-Domain-Name': 'domain',
                         'X-Project-Domain-Id': 'project_domain_id',
@@ -159,10 +160,12 @@ class FakeAssembly(mock.Mock):
         self.components = [FakeComponent()]
         self.status = 'BUILDING'
         self.application_uri = 'test_uri'
+        self.trust_id = 'trust_worthy'
 
     def as_dict(self):
         return dict(user_id=self.user_id,
                     project_id=self.project_id,
+                    application_uri=self.application_uri,
                     uuid=self.uuid,
                     id=self.id,
                     name=self.name,
